@@ -251,11 +251,11 @@ class Application(BaseApplication):
         # display the error cleanly unless the user uses verbose or debug
         self._configure_global_options(io)
 
-        self._load_plugins(io)
-
-        exit_code: int = 1
-
         with directory(self._working_directory):
+            self._load_plugins(io)
+
+            exit_code: int = 1
+
             try:
                 exit_code = super()._run(io)
             except PoetryRuntimeError as e:
@@ -581,7 +581,7 @@ class Application(BaseApplication):
         env = env_manager.create_venv()
 
         if env.is_venv() and io.is_verbose():
-            io.write_line(f"Using virtualenv: <comment>{env.path}</>")
+            io.write_error_line(f"Using virtualenv: <comment>{env.path}</>")
 
         command.set_env(env)
 
@@ -616,6 +616,7 @@ class Application(BaseApplication):
             poetry.pool,
             poetry.config,
             disable_cache=poetry.disable_cache,
+            build_constraints=poetry.build_constraints,
         )
         command.set_installer(installer)
 
