@@ -30,7 +30,7 @@ from poetry.packages import DependencyPackage
 from poetry.packages.direct_origin import DirectOrigin
 from poetry.packages.package_collection import PackageCollection
 from poetry.puzzle.exceptions import OverrideNeededError
-from poetry.utils.helpers import get_file_hash
+from poetry.repositories.repository_pool import Priority
 
 
 if TYPE_CHECKING:
@@ -38,6 +38,7 @@ if TYPE_CHECKING:
     from collections.abc import Collection
     from collections.abc import Iterable
     from collections.abc import Iterator
+    from collections.abc import Sequence
     from pathlib import Path
 
     from cleo.io.io import IO
@@ -47,6 +48,7 @@ if TYPE_CHECKING:
     from poetry.core.packages.directory_dependency import DirectoryDependency
     from poetry.core.packages.file_dependency import FileDependency
     from poetry.core.packages.package import Package
+    from poetry.core.packages.package import PackageFile
     from poetry.core.packages.url_dependency import URLDependency
     from poetry.core.packages.vcs_dependency import VCSDependency
     from poetry.core.version.markers import BaseMarker
@@ -150,6 +152,7 @@ class Provider:
             )
 
         self.get_package_from_pool = functools.cache(self._pool.package)
+        self._refreshed: set[tuple[str, Version, str | None]] = set()
 
     @property
     def pool(self) -> RepositoryPool:
@@ -201,9 +204,12 @@ class Provider:
         original_python_constraint = self._package_python_constraint
 
         self._env = env
+        # We use the stable version here to improve support of environments of Python pre-release
+        # versions, e.g. Python 3.14rc2. Without using the stable version here, a dependency with
+        # a marker like `python_version >= "3.14"` would not be installed.
         self._package_python_constraint = Version.parse(
             env.marker_env["python_full_version"]
-        )
+        ).stable
 
         try:
             yield self
@@ -339,13 +345,6 @@ class Provider:
         if dependency.base is not None:
             package.root_dir = dependency.base
 
-        package.files = [
-            {
-                "file": dependency.path.name,
-                "hash": "sha256:" + get_file_hash(dependency.full_path),
-            }
-        ]
-
         return package
 
     def _search_for_directory(self, dependency: DirectoryDependency) -> Package:
@@ -453,6 +452,16 @@ class Provider:
             for dep in self._get_dependencies_with_overrides(dependencies, package)
         ]
 
+    @staticmethod
+    def _files_list_for_cmp(files: Sequence[PackageFile]) -> list[str]:
+        """
+        :return: A list of strings representing the files and their hashes, for
+            the purpose of comparing the file list to another one.
+            We only use file+hash, because that's what uniquely identifies the file,
+            the other properties (like URL) are not relevant.
+        """
+        return sorted(f["file"] + f["hash"] for f in files)
+
     def complete_package(
         self, dependency_package: DependencyPackage
     ) -> DependencyPackage:
@@ -467,14 +476,34 @@ class Provider:
         elif package.is_direct_origin():
             requires = package.requires
         else:
-            dependency_package = DependencyPackage(
-                dependency,
-                self.get_package_from_pool(
+            if (
+                package.pretty_name,
+                package.version,
+                dependency.source_name,
+            ) in self._refreshed:
+                # circumvent lru_cache to avoid unnecessary refresh
+                pool_package = self.pool.package(
                     package.pretty_name,
                     package.version,
                     repository_name=dependency.source_name,
-                ),
-            )
+                )
+            else:
+                pool_package = self.get_package_from_pool(
+                    package.pretty_name,
+                    package.version,
+                    repository_name=dependency.source_name,
+                )
+            if package.files and self._files_list_for_cmp(
+                package.files
+            ) != self._files_list_for_cmp(pool_package.files):
+                # This happens if additional artifacts are uploaded later. Either our own cache
+                # is outdated or the lockfile has been created with an outdated cache.
+                # Refresh to cover the first case. (It does not hurt much in the second case.)
+                pool_package = self.pool.refresh(pool_package)
+                self._refreshed.add(
+                    (package.pretty_name, package.version, dependency.source_name)
+                )
+            dependency_package = DependencyPackage(dependency, pool_package)
 
             package = dependency_package.package
             dependency = dependency_package.dependency
@@ -613,7 +642,7 @@ class Provider:
 
             if len(duplicates_by_extras) == 1:
                 active_extras = (
-                    self._active_root_extras if package.is_root() else dependency.extras
+                    self._active_root_extras if package.is_root() else found_extras
                 )
                 deps = self._resolve_overlapping_markers(package, deps, active_extras)
             else:
@@ -753,6 +782,14 @@ class Provider:
             if package.satisfies(dependency):
                 if explicit_source := self._explicit_sources.get(dependency.name):
                     dependency.source_name = explicit_source
+                elif (
+                    not dependency.source_name
+                    and package.source_type == "legacy"
+                    and package.source_reference
+                    and self._pool.get_priority(package.source_reference)
+                    == Priority.EXPLICIT
+                ):
+                    continue
                 return DependencyPackage(dependency, package)
         return None
 
@@ -1008,7 +1045,7 @@ class Provider:
 
         :param extras: the values to add to the 'extra' marker value
         """
-        result = self._env.marker_env.copy() if self._env is not None else {}
+        result = dict(self._env.marker_env) if self._env is not None else {}
         if extras is not None:
             assert "extra" not in result, (
                 "'extra' marker key is already present in environment"
