@@ -26,7 +26,9 @@ def venv_name(app: PoetryTestApplication) -> str:
 
 @pytest.fixture
 def venv_cache(tmp_path: Path) -> Path:
-    return tmp_path
+    path = tmp_path / "venv_cache"
+    path.mkdir()
+    return path
 
 
 @pytest.fixture(scope="module")
@@ -65,7 +67,8 @@ def venvs_in_project_dir(app: PoetryTestApplication) -> Iterator[Path]:
     try:
         yield venv_dir
     finally:
-        venv_dir.rmdir()
+        if venv_dir.exists():
+            venv_dir.rmdir()
 
 
 @pytest.fixture
