@@ -11,8 +11,10 @@ import tomlkit
 
 from poetry.core.constraints.version import Version
 
+from poetry.console.commands.env.use import EnvUseCommand
 from poetry.toml.file import TOMLFile
 from poetry.utils.env import MockEnv
+from poetry.utils.env.python.exceptions import NoCompatiblePythonVersionFoundError
 from tests.console.commands.env.helpers import build_venv
 from tests.console.commands.env.helpers import check_output_wrapper
 
@@ -23,6 +25,7 @@ if TYPE_CHECKING:
     from cleo.testers.command_tester import CommandTester
     from pytest_mock import MockerFixture
 
+    from poetry.utils.env.base_env import PythonVersion
     from tests.types import CommandTesterFactory
     from tests.types import MockedPythonRegister
 
@@ -35,11 +38,11 @@ def setup(mocker: MockerFixture) -> None:
 
 @pytest.fixture(autouse=True)
 def mock_subprocess_calls(
-    setup: None, current_python: tuple[int, int, int], mocker: MockerFixture
+    setup: None, current_python: PythonVersion, mocker: MockerFixture
 ) -> None:
     mocker.patch(
         "subprocess.check_output",
-        side_effect=check_output_wrapper(Version.from_parts(*current_python)),
+        side_effect=check_output_wrapper(Version.from_parts(*current_python[:3])),
     )
     mocker.patch(
         "subprocess.Popen.communicate",
@@ -65,6 +68,10 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
     mock_build_env = mocker.patch(
         "poetry.utils.env.EnvManager.build_venv", side_effect=build_venv
     )
+    envs_file = TOMLFile(venv_cache / "envs.toml")
+
+    assert not envs_file.exists()
+    assert not list(venv_cache.iterdir())
 
     tester.execute("3.7")
 
@@ -80,7 +87,6 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
         prompt="simple-project-py3.7",
     )
 
-    envs_file = TOMLFile(venv_cache / "envs.toml")
     assert envs_file.exists()
     envs: dict[str, Any] = envs_file.read()
     assert envs[venv_name]["minor"] == "3.7"
@@ -93,9 +99,36 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
     assert tester.io.fetch_output() == f"Using virtualenv: {venv_py37}\n"
 
 
+@pytest.mark.parametrize("use_poetry_python", [True, False])
+def test_activate_does_not_activate_non_existing_virtualenv_with_unsupported_version(
+    tester: CommandTester,
+    venv_cache: Path,
+    venv_name: str,
+    venvs_in_cache_config: None,
+    mocked_python_register: MockedPythonRegister,
+    with_no_active_python: MagicMock,
+    use_poetry_python: bool,
+) -> None:
+    mocked_python_register("3.7.1")
+    mocked_python_register("3.8.2")
+    command = tester.command
+    assert isinstance(command, EnvUseCommand)
+    command.poetry.package.python_versions = "~3.8"
+    command.poetry.config.merge(
+        {"virtualenvs": {"use-poetry-python": use_poetry_python}}
+    )
+
+    assert not list(venv_cache.iterdir())
+
+    with pytest.raises(NoCompatiblePythonVersionFoundError):
+        tester.execute("3.7")
+
+    assert not list(venv_cache.iterdir())
+
+
 def test_get_prefers_explicitly_activated_virtualenvs_over_env_var(
     tester: CommandTester,
-    current_python: tuple[int, int, int],
+    current_python: PythonVersion,
     venv_cache: Path,
     venv_name: str,
     venvs_in_cache_config: None,
@@ -127,7 +160,7 @@ Using virtualenv: {venv_dir}
 def test_get_prefers_explicitly_activated_non_existing_virtualenvs_over_env_var(
     mocker: MockerFixture,
     tester: CommandTester,
-    current_python: tuple[int, int, int],
+    current_python: PythonVersion,
     venv_cache: Path,
     venv_name: str,
     venvs_in_cache_config: None,
