@@ -14,10 +14,12 @@ from poetry.core.pyproject.exceptions import PyProjectError
 
 from poetry.config.config_source import ConfigSource
 from poetry.config.config_source import PropertyNotFoundError
+from poetry.console.commands.config import ConfigCommand
 from poetry.console.commands.install import InstallCommand
 from poetry.factory import Factory
 from poetry.repositories.legacy_repository import LegacyRepository
 from tests.conftest import Config
+from tests.helpers import flatten_dict
 
 
 if TYPE_CHECKING:
@@ -36,6 +38,12 @@ def tester(command_tester_factory: CommandTesterFactory) -> CommandTester:
     return command_tester_factory("config")
 
 
+def test_config_command_in_sync_with_config_class() -> None:
+    assert set(ConfigCommand().unique_config_values) == set(
+        flatten_dict(Config.default_config)
+    )
+
+
 def test_show_config_with_local_config_file_empty(
     tester: CommandTester, mocker: MockerFixture
 ) -> None:
@@ -62,7 +70,7 @@ installer.max-workers = null
 installer.no-binary = null
 installer.only-binary = null
 installer.parallel = true
-installer.re-resolve = true
+installer.re-resolve = false
 keyring.enabled = true
 python.installation-dir = {json.dumps(str(Path("{data-dir}/python")))}  # {config_data_dir / "python"}
 requests.max-retries = 0
@@ -97,7 +105,7 @@ installer.max-workers = null
 installer.no-binary = null
 installer.only-binary = null
 installer.parallel = true
-installer.re-resolve = true
+installer.re-resolve = false
 keyring.enabled = true
 python.installation-dir = {json.dumps(str(Path("{data-dir}/python")))}  # {config_data_dir / "python"}
 requests.max-retries = 0
@@ -153,7 +161,7 @@ installer.max-workers = null
 installer.no-binary = null
 installer.only-binary = null
 installer.parallel = true
-installer.re-resolve = true
+installer.re-resolve = false
 keyring.enabled = true
 python.installation-dir = {json.dumps(str(Path("{data-dir}/python")))}  # {config_data_dir / "python"}
 requests.max-retries = 0
@@ -187,7 +195,7 @@ installer.max-workers = null
 installer.no-binary = null
 installer.only-binary = null
 installer.parallel = true
-installer.re-resolve = true
+installer.re-resolve = false
 keyring.enabled = true
 python.installation-dir = {json.dumps(str(Path("{data-dir}/python")))}  # {config_data_dir / "python"}
 requests.max-retries = 0
@@ -322,7 +330,7 @@ installer.max-workers = null
 installer.no-binary = null
 installer.only-binary = null
 installer.parallel = true
-installer.re-resolve = true
+installer.re-resolve = false
 keyring.enabled = true
 python.installation-dir = {json.dumps(str(Path("{data-dir}/python")))}  # {config_data_dir / "python"}
 requests.max-retries = 0
@@ -365,7 +373,7 @@ installer.max-workers = null
 installer.no-binary = null
 installer.only-binary = null
 installer.parallel = true
-installer.re-resolve = true
+installer.re-resolve = false
 keyring.enabled = true
 python.installation-dir = {json.dumps(str(Path("{data-dir}/python")))}  # {config_data_dir / "python"}
 repositories.foo.url = "https://foo.bar/simple/"
