@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import subprocess
-import sys
 
 from typing import TYPE_CHECKING
 
@@ -188,8 +187,7 @@ def test_run_console_scripts_of_editable_dependencies_on_windows(
 
     cmd_script_file = tmp_venv._bin_dir / "quix.cmd"
     # `/b` ensures we only exit the script instead of any cmd.exe proc that called it
-    encoding = "locale" if sys.version_info >= (3, 10) else None
-    cmd_script_file.write_text("exit /b 123", encoding=encoding)
+    cmd_script_file.write_text("exit /b 123", encoding="locale")
     # We prove that the CMD script executed successfully by verifying the exit code
     # matches what we wrote in the script
     assert tester.execute("quix") == 123
