@@ -1,9 +1,11 @@
 from __future__ import annotations
 
-from pathlib import Path
 from typing import TYPE_CHECKING
 
+import pytest
+
 from poetry.factory import Factory
+from poetry.puzzle.provider import IncompatibleConstraintsError
 from tests.mixology.helpers import add_to_repo
 from tests.mixology.helpers import check_solver_result
 
@@ -13,11 +15,12 @@ if TYPE_CHECKING:
 
     from poetry.repositories import Repository
     from tests.mixology.version_solver.conftest import Provider
+    from tests.types import FixtureDirGetter
 
 
 def test_no_version_matching_constraint(
     root: ProjectPackage, provider: Provider, repo: Repository
-):
+) -> None:
     root.add_dependency(Factory.create_dependency("foo", "^1.0"))
 
     add_to_repo(repo, "foo", "2.0.0")
@@ -35,7 +38,7 @@ def test_no_version_matching_constraint(
 
 def test_no_version_that_matches_combined_constraints(
     root: ProjectPackage, provider: Provider, repo: Repository
-):
+) -> None:
     root.add_dependency(Factory.create_dependency("foo", "1.0.0"))
     root.add_dependency(Factory.create_dependency("bar", "1.0.0"))
 
@@ -58,7 +61,7 @@ So, because myapp depends on both foo (1.0.0) and bar (1.0.0), version solving f
 
 def test_disjoint_constraints(
     root: ProjectPackage, provider: Provider, repo: Repository
-):
+) -> None:
     root.add_dependency(Factory.create_dependency("foo", "1.0.0"))
     root.add_dependency(Factory.create_dependency("bar", "1.0.0"))
 
@@ -68,9 +71,9 @@ def test_disjoint_constraints(
     add_to_repo(repo, "shared", "4.0.0")
 
     error = """\
-Because bar (1.0.0) depends on shared (>3.0.0)
- and foo (1.0.0) depends on shared (<=2.0.0),\
- bar (1.0.0) is incompatible with foo (1.0.0).
+Because foo (1.0.0) depends on shared (<=2.0.0)
+ and bar (1.0.0) depends on shared (>3.0.0),\
+ foo (1.0.0) is incompatible with bar (1.0.0).
 So, because myapp depends on both foo (1.0.0) and bar (1.0.0), version solving failed.\
 """
 
@@ -80,7 +83,7 @@ So, because myapp depends on both foo (1.0.0) and bar (1.0.0), version solving f
 
 def test_disjoint_root_constraints(
     root: ProjectPackage, provider: Provider, repo: Repository
-):
+) -> None:
     root.add_dependency(Factory.create_dependency("foo", "1.0.0"))
     root.add_dependency(Factory.create_dependency("foo", "2.0.0"))
 
@@ -88,31 +91,43 @@ def test_disjoint_root_constraints(
     add_to_repo(repo, "foo", "2.0.0")
 
     error = """\
-Because myapp depends on both foo (1.0.0) and foo (2.0.0), version solving failed."""
+Incompatible constraints in requirements of myapp (0.0.0):
+foo (==1.0.0)
+foo (==2.0.0)"""
 
-    check_solver_result(root, provider, error=error)
+    with pytest.raises(IncompatibleConstraintsError) as e:
+        check_solver_result(root, provider, error=error)
+
+    assert str(e.value) == error
 
 
 def test_disjoint_root_constraints_path_dependencies(
-    root: ProjectPackage, provider: Provider, repo: Repository
-):
+    root: ProjectPackage,
+    provider: Provider,
+    repo: Repository,
+    fixture_dir: FixtureDirGetter,
+) -> None:
     provider.set_package_python_versions("^3.7")
-    fixtures = Path(__file__).parent.parent.parent / "fixtures"
-    project_dir = fixtures.joinpath("with_conditional_path_deps")
+    project_dir = fixture_dir("with_conditional_path_deps")
     dependency1 = Factory.create_dependency("demo", {"path": project_dir / "demo_one"})
     root.add_dependency(dependency1)
     dependency2 = Factory.create_dependency("demo", {"path": project_dir / "demo_two"})
     root.add_dependency(dependency2)
 
-    error = (
-        f"Because myapp depends on both {str(dependency1).replace('*', '1.2.3')} "
-        f"and {str(dependency2).replace('*', '1.2.3')}, version solving failed."
-    )
+    error = f"""\
+Incompatible constraints in requirements of myapp (0.0.0):
+demo @ {project_dir.as_uri()}/demo_two (1.2.3)
+demo @ {project_dir.as_uri()}/demo_one (1.2.3)"""
 
-    check_solver_result(root, provider, error=error)
+    with pytest.raises(IncompatibleConstraintsError) as e:
+        check_solver_result(root, provider, error=error)
+
+    assert str(e.value) == error
 
 
-def test_no_valid_solution(root: ProjectPackage, provider: Provider, repo: Repository):
+def test_no_valid_solution(
+    root: ProjectPackage, provider: Provider, repo: Repository
+) -> None:
     root.add_dependency(Factory.create_dependency("a", "*"))
     root.add_dependency(Factory.create_dependency("b", "*"))
 
@@ -135,7 +150,7 @@ So, because myapp depends on b (*), version solving failed."""
 
 def test_package_with_the_same_name_gives_clear_error_message(
     root: ProjectPackage, provider: Provider, repo: Repository
-):
+) -> None:
     pkg_name = "a"
     root.add_dependency(Factory.create_dependency(pkg_name, "*"))
     add_to_repo(repo, pkg_name, "1.0.0", deps={pkg_name: "1.0.0"})
