@@ -8,6 +8,7 @@ from typing import TYPE_CHECKING
 from typing import Any
 
 import pytest
+import responses
 
 from poetry.core.utils.helpers import parse_requires
 from requests.exceptions import ChunkedEncodingError
@@ -21,11 +22,11 @@ from poetry.utils.helpers import get_highest_priority_hash_type
 
 
 if TYPE_CHECKING:
-    from httpretty import httpretty
-    from httpretty.core import HTTPrettyRequest
+    from requests import PreparedRequest
 
     from tests.conftest import Config
     from tests.types import FixtureDirGetter
+    from tests.types import HttpResponse
 
 
 def test_parse_requires() -> None:
@@ -137,88 +138,87 @@ def test_guaranteed_hash(
 
 
 def test_download_file(
-    http: type[httpretty], fixture_dir: FixtureDirGetter, tmp_path: Path
+    http: responses.RequestsMock, fixture_dir: FixtureDirGetter, tmp_path: Path
 ) -> None:
     file_path = fixture_dir("distributions") / "demo-0.1.0.tar.gz"
     url = "https://foo.com/demo-0.1.0.tar.gz"
-    http.register_uri(http.GET, url, body=file_path.read_bytes())
+    http.get(url, body=file_path.read_bytes())
     dest = tmp_path / "demo-0.1.0.tar.gz"
 
     download_file(url, dest)
 
     expect_sha_256 = "9fa123ad707a5c6c944743bf3e11a0e80d86cb518d3cf25320866ca3ef43e2ad"
     assert get_file_hash(dest) == expect_sha_256
-    assert http.last_request().headers["Accept-Encoding"] == "Identity"
+    assert http.calls[-1].request.headers["Accept-Encoding"] == "Identity"
 
 
 def test_download_file_recover_from_error(
-    http: type[httpretty], fixture_dir: FixtureDirGetter, tmp_path: Path
+    http: responses.RequestsMock, fixture_dir: FixtureDirGetter, tmp_path: Path
 ) -> None:
     file_path = fixture_dir("distributions") / "demo-0.1.0.tar.gz"
     file_body = file_path.read_bytes()
     file_length = len(file_body)
     url = "https://foo.com/demo-0.1.0.tar.gz"
 
-    def handle_request(
-        request: HTTPrettyRequest, uri: str, response_headers: dict[str, Any]
-    ) -> tuple[int, dict[str, Any], bytes]:
+    def handle_request(request: PreparedRequest) -> HttpResponse:
         if request.headers.get("Range") is None:
-            response_headers["Content-Length"] = str(file_length)
-            response_headers["Accept-Ranges"] = "bytes"
+            response_headers = {
+                "Content-Length": str(file_length),
+                "Accept-Ranges": "bytes",
+            }
             return 200, response_headers, file_body[: file_length // 2]
         else:
             start = int(
                 request.headers.get("Range", "bytes=0-").split("=")[1].split("-")[0]
             )
+            response_headers = {"Content-Length": str(len(file_body[start:]))}
             return 206, response_headers, file_body[start:]
 
-    http.register_uri(http.GET, url, body=handle_request)
+    http.add_callback(responses.GET, url, callback=handle_request)
     dest = tmp_path / "demo-0.1.0.tar.gz"
 
     download_file(url, dest, chunk_size=file_length // 2, max_retries=1)
 
     expect_sha_256 = "9fa123ad707a5c6c944743bf3e11a0e80d86cb518d3cf25320866ca3ef43e2ad"
     assert get_file_hash(dest) == expect_sha_256
-    assert http.last_request().headers["Accept-Encoding"] == "Identity"
-    assert http.last_request().headers["Range"] == f"bytes={file_length // 2}-"
+    assert http.calls[-1].request.headers["Accept-Encoding"] == "Identity"
+    assert http.calls[-1].request.headers["Range"] == f"bytes={file_length // 2}-"
 
 
 def test_download_file_fail_when_no_range(
-    http: type[httpretty], fixture_dir: FixtureDirGetter, tmp_path: Path
+    http: responses.RequestsMock, fixture_dir: FixtureDirGetter, tmp_path: Path
 ) -> None:
     file_path = fixture_dir("distributions") / "demo-0.1.0.tar.gz"
     file_body = file_path.read_bytes()
     file_length = len(file_body)
     url = "https://foo.com/demo-0.1.0.tar.gz"
 
-    def handle_request(
-        request: HTTPrettyRequest, uri: str, response_headers: dict[str, Any]
-    ) -> tuple[int, dict[str, Any], bytes]:
-        response_headers["Content-Length"] = str(file_length)
+    def handle_request(request: PreparedRequest) -> HttpResponse:
+        response_headers = {"Content-Length": str(file_length)}
         return 200, response_headers, file_body[: file_length // 2]
 
-    http.register_uri(http.GET, url, body=handle_request)
+    http.add_callback(responses.GET, url, callback=handle_request)
     dest = tmp_path / "demo-0.1.0.tar.gz"
     with pytest.raises(ChunkedEncodingError):
         download_file(url, dest, chunk_size=file_length // 2, max_retries=1)
 
 
 def test_download_file_fail_when_first_chunk_failed(
-    http: type[httpretty], fixture_dir: FixtureDirGetter, tmp_path: Path
+    http: responses.RequestsMock, fixture_dir: FixtureDirGetter, tmp_path: Path
 ) -> None:
     file_path = fixture_dir("distributions") / "demo-0.1.0.tar.gz"
     file_body = file_path.read_bytes()
     file_length = len(file_body)
     url = "https://foo.com/demo-0.1.0.tar.gz"
 
-    def handle_request(
-        request: HTTPrettyRequest, uri: str, response_headers: dict[str, Any]
-    ) -> tuple[int, dict[str, Any], bytes]:
-        response_headers["Content-Length"] = str(file_length)
-        response_headers["Accept-Ranges"] = "bytes"
+    def handle_request(request: PreparedRequest) -> tuple[int, dict[str, Any], bytes]:
+        response_headers = {
+            "Content-Length": str(file_length),
+            "Accept-Ranges": "bytes",
+        }
         return 200, response_headers, file_body[: file_length // 2]
 
-    http.register_uri(http.GET, url, body=handle_request)
+    http.add_callback(responses.GET, url, callback=handle_request)
     dest = tmp_path / "demo-0.1.0.tar.gz"
     with pytest.raises(ChunkedEncodingError):
         download_file(url, dest, chunk_size=file_length, max_retries=1)
@@ -240,7 +240,7 @@ def test_highest_priority_hash_type(hash_types: set[str], expected: str | None)
 @pytest.mark.parametrize("accepts_ranges", [False, True])
 @pytest.mark.parametrize("raise_accepts_ranges", [False, True])
 def test_download_file_raise_accepts_ranges(
-    http: type[httpretty],
+    http: responses.RequestsMock,
     fixture_dir: FixtureDirGetter,
     tmp_path: Path,
     accepts_ranges: bool,
@@ -248,16 +248,15 @@ def test_download_file_raise_accepts_ranges(
 ) -> None:
     filename = "demo-0.1.0-py2.py3-none-any.whl"
 
-    def handle_request(
-        request: HTTPrettyRequest, uri: str, response_headers: dict[str, Any]
-    ) -> tuple[int, dict[str, Any], bytes]:
+    def handle_request(request: PreparedRequest) -> tuple[int, dict[str, Any], bytes]:
         file_path = fixture_dir("distributions") / filename
+        response_headers = {}
         if accepts_ranges:
             response_headers["Accept-Ranges"] = "bytes"
         return 200, response_headers, file_path.read_bytes()
 
     url = f"https://foo.com/{filename}"
-    http.register_uri(http.GET, url, body=handle_request)
+    http.add_callback(responses.GET, url, callback=handle_request)
     dest = tmp_path / filename
 
     if accepts_ranges and raise_accepts_ranges:
@@ -271,7 +270,7 @@ def test_download_file_raise_accepts_ranges(
 
 def test_downloader_uses_authenticator_by_default(
     config: Config,
-    http: type[httpretty],
+    http: responses.RequestsMock,
     tmp_working_directory: Path,
 ) -> None:
     import poetry.utils.authenticator
@@ -286,8 +285,7 @@ def test_downloader_uses_authenticator_by_default(
         }
     )
 
-    http.register_uri(
-        http.GET,
+    http.get(
         re.compile("^https?://foo.bar/(.+?)$"),
     )
 
@@ -296,7 +294,7 @@ def test_downloader_uses_authenticator_by_default(
         tmp_working_directory / "foo-0.1.0.tar.gz",
     )
 
-    request = http.last_request()
+    request = http.calls[-1].request
     basic_auth = base64.b64encode(b"bar:baz").decode()
     assert request.headers["Authorization"] == f"Basic {basic_auth}"
 
